@@ -6,7 +6,7 @@
 
    GNU RCS is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    GNU RCS is distributed in the hope that it will be useful,
@@ -781,7 +781,7 @@ full (struct divvy *to, struct fro *f)
 
   /* Validate ‘GROK (head)’.  */
   if (repo->head && !FIND_NY (repo->head))
-    fatal_syntax (g->head_lno, "repository head names a %s `%s'",
+    fatal_syntax (g->head_lno, "RCS file head names a %s `%s'",
                   ks_ner, repo->head);
 
   /* Link deltas (via ‘branches’ and ‘next’).  */
