@@ -8,7 +8,7 @@
 
    GNU RCS is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    GNU RCS is distributed in the hope that it will be useful,
@@ -563,8 +563,8 @@ first_meaningful_symbolic_name (void)
 Options:
   -f[REV]       Force new entry, even if no content changed.
   -I[REV]       Interactive.
-  -i[REV]       Initial checkin; error if repository already exists.
-  -j[REV]       Just checkin, don't initialize; error if repository does not exist.
+  -i[REV]       Initial checkin; error if RCS file already exists.
+  -j[REV]       Just checkin, don't init; error if RCS file does not exist.
   -k[REV]       Compute revision from working file keywords.
   -q[REV]       Quiet mode.
   -r[REV]       Do normal checkin, if REV is specified;
@@ -579,14 +579,15 @@ Options:
   -sSTATE       Set state to STATE.
   -t-TEXT       Set description to TEXT.
   -tFILENAME    Set description from text read from FILENAME.
-  -T            Set the repository's modification time to the new revision's
-                time if the former precedes the latter and there is a new
-                revision; preserve the repository's modification time otherwise.
+  -T            Set the RCS file's modification time to the new
+                revision's time if the former precedes the latter and there
+                is a new revision; preserve the RCS file's modification
+                time otherwise.
   -V            Like --version.
   -VN           Emulate RCS version N.
   -wWHO         Use WHO as the author.
   -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify repository names.
+                used to identify RCS file names.
   -zZONE        Specify date output format in keyword-substitution
                 and also the default timezone for -dDATE.
 
