@@ -8,7 +8,7 @@
 
    GNU RCS is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    GNU RCS is distributed in the hope that it will be useful,
@@ -1055,12 +1055,12 @@ buildtree (void)
 /*:help
 [options] file ...
 Options:
-  -i              Create and initialize a new repository.
+  -i              Create and initialize a new RCS file.
   -L              Set strict locking.
   -U              Set non-strict locking.
   -M              Don't send mail when breaking someone else's lock.
-  -T              Preserve the modification time on the repository
-                  unless a revision is removed.
+  -T              Preserve the modification time on the
+                  RCS file unless a revision is removed.
   -I              Interactive.
   -q              Quiet mode.
   -aLOGINS        Append LOGINS (comma-separated) to access-list.
@@ -1083,12 +1083,12 @@ Options:
                     :REV      -- beginning of branch to REV
                     REV:      -- REV to end of branch
   -sSTATE[:REV]   Set state of REV to STATE.
-  -t-TEXT         Replace description in repository with TEXT.
-  -tFILENAME      Replace description in repository with contents of FILENAME.
+  -t-TEXT         Set description in RCS file to TEXT.
+  -tFILENAME      Set description in RCS file to contents of FILENAME.
   -V              Like --version.
   -VN             Emulate RCS version N.
   -xSUFF          Specify SUFF as a slash-separated list of suffixes
-                  used to identify repository names.
+                  used to identify RCS file names.
   -zZONE          No effect; included for compatibility with other commands.
 
 REV defaults to the latest revision on the default branch.
