@@ -7,7 +7,7 @@
 
    GNU RCS is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    GNU RCS is distributed in the hope that it will be useful,
@@ -122,12 +122,12 @@ Options:
   -n[REV]       Dry run (no act, don't operate).
   -q[REV]       Quiet mode.
   -kSUBST       Substitute using mode SUBST (see co(1)).
-  -T            Preserve the modification time on the repository even
-                if the repository changes because a lock is removed.
+  -T            Preserve the modification time on the RCS file
+                even if it changes because a lock is removed.
   -V            Like --version.
   -VN           Emulate RCS version N.
   -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify repository names.
+                used to identify RCS file names.
   -zZONE        Specify date output format in keyword-substitution.
 
 REV defaults to the latest revision on the default branch.
