@@ -8,7 +8,7 @@
 
    GNU RCS is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 2 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    GNU RCS is distributed in the hope that it will be useful,
@@ -739,8 +739,8 @@ putrevpairs (char const *b, char const *e, bool sawsep)
 /*:help
 [options] file ...
 Options:
-  -L            Ignore repositories with no locks set.
-  -R            Print only the name of the repository.
+  -L            Ignore RCS files with no locks set.
+  -R            Print the RCS file name only.
   -h            Print only the "header" information.
   -t            Like -h, but also include the description.
   -N            Omit symbolic names.
@@ -763,7 +763,7 @@ Options:
   -V            Like --version.
   -VN           Emulate RCS version N.
   -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify repository names.
+                used to identify RCS file names.
   -zZONE        Specify date output format in keyword-substitution.
   -q            No effect, included for consistency with other commands.
 */
